@@ -13,19 +13,20 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-embed.h 6749 2006-12-17 19:17:36Z chpe $
+ *  $Id$
  */
 
 #ifndef EPHY_EMBED_H
 #define EPHY_EMBED_H
 
 #include "ephy-embed-event.h"
+#include "ephy-history-item.h"
 
 #include <glib-object.h>
 #include <glib.h>
-#include <gtk/gtkwidget.h>
+#include <gtk/gtk.h>
 
 G_BEGIN_DECLS
 
@@ -66,7 +67,7 @@ typedef enum
 typedef enum
 {
 	EPHY_EMBED_LOAD_FLAGS_NONE			= 1 << 0,
-	EPHY_EMBED_LOAD_FLAGS_ALLOW_THIRD_PARTY_FIXUP 	= 1 << 1,
+	EPHY_EMBED_LOAD_FLAGS_ALLOW_THIRD_PARTY_FIXUP	= 1 << 1,
 } EphyEmbedLoadFlags;
 
 #define EPHY_EMBED_CHROME_ALL (EPHY_EMBED_CHROME_MENUBAR |	\
@@ -101,24 +102,24 @@ typedef enum
 	EPHY_EMBED_DOCUMENT_OTHER
 } EphyEmbedDocumentType;
 
+typedef enum
+{
+	EPHY_EMBED_NAV_UP	= 1 << 0,
+	EPHY_EMBED_NAV_BACK	= 1 << 1,
+	EPHY_EMBED_NAV_FORWARD	= 1 << 2
+} EphyEmbedNavigationFlags;
+
+typedef enum
+{
+	EPHY_EMBED_ADDRESS_EXPIRE_NOW,
+	EPHY_EMBED_ADDRESS_EXPIRE_NEXT,
+	EPHY_EMBED_ADDRESS_EXPIRE_CURRENT
+} EphyEmbedAddressExpire;
+
 struct _EphyEmbedIface
 {
 	GTypeInterface base_iface;
 
-	/* Signals that we inherit from gtkmozembed
-	 *
-	 * void (* net_stop)     (GtkMozEmbed *embed);
-	 * void (* title)        (EphyEmbed *embed);
-	 * void (* visibility)   (EphyEmbed *embed,
-	 *			  gboolean visibility);
-	 * void (* destroy_brsr) (EphyEmbed *embed);
-	 * void (* size_to)      (EphyEmbed *embed,
-	 *			  int width,
-	 *			  int height);
-	 * gint (* open_uri)	 (EphyEmbed *embed,
-	 *			  const char *url);
-	 */	
-
 	int	 (* context_menu)	(EphyEmbed *embed,
 					 EphyEmbedEvent *event);
 	void	 (* favicon)		(EphyEmbed *embed,
@@ -131,31 +132,22 @@ struct _EphyEmbedIface
 					 const char *type,
 					 const char *title,
 					 const char *address);
-	void	 (* location)		(EphyEmbed *embed,
-					 const char *location);
-	void	 (* net_state)		(EphyEmbed *embed,
-					 const char *uri,
-					 EphyEmbedNetState state);
 	gboolean (* dom_mouse_click)	(EphyEmbed *embed,
 					 EphyEmbedEvent *event);
 	gboolean (* dom_mouse_down)	(EphyEmbed *embed,
 					 EphyEmbedEvent *event);
-	void     (* dom_content_loaded)	(EphyEmbed *embed,
+	void	 (* dom_content_loaded) (EphyEmbed *embed,
 					 gpointer event);
 	void	 (* popup_blocked)	(EphyEmbed *embed,
 					 const char *address,
 					 const char *target,
 					 const char *features);
-	void	 (* security_change)	(EphyEmbed *embed,
-					 EphyEmbedSecurityLevel level);
 	void	 (* zoom_change)	(EphyEmbed *embed,
 					 float new_zoom);
-	void	 (* content_change)	(EphyEmbed *embed,
-					 const char *uri);
 	void	 (* content_blocked)	(EphyEmbed *embed,
 					 const char *uri);
 	gboolean (* modal_alert)	(EphyEmbed *embed);
-	void	 (* modal_alert_closed)	(EphyEmbed *embed);
+	void	 (* modal_alert_closed) (EphyEmbed *embed);
 	void	 (* document_type)	(EphyEmbed *embed,
 					 EphyEmbedDocumentType type);
 	void	 (* new_window)		(EphyEmbed *embed,
@@ -164,78 +156,91 @@ struct _EphyEmbedIface
 					 GdkEventKey *event);
 	gboolean (* close_request)	(EphyEmbed *embed);
 
+	void	 (* new_document_now)	(EphyEmbed *embed,
+					 const char *uri);
+
 	/* Methods  */
-	void		   (* load_url)			(EphyEmbed *embed,
-							 const char *url);
-	void		   (* load)			(EphyEmbed *embed,
-							 const char *url,
-							 EphyEmbedLoadFlags flags,
-							 EphyEmbed *referring_embed);
-	void		   (* stop_load)		(EphyEmbed *embed);
-	void		   (* reload)			(EphyEmbed *embed,
-							 gboolean force);
-	gboolean	   (* can_go_back)		(EphyEmbed *embed);
-	gboolean	   (* can_go_forward)		(EphyEmbed *embed);
-	gboolean	   (* can_go_up)		(EphyEmbed *embed);
-	GSList *	   (* get_go_up_list)		(EphyEmbed *embed);
-	void		   (* go_back)			(EphyEmbed *embed);
-	void		   (* go_forward)		(EphyEmbed *embed);
-	void		   (* go_up)			(EphyEmbed *embed);
-
-	char *		   (* get_title)		(EphyEmbed *embed);
-	char *		   (* get_location)		(EphyEmbed *embed,
-							 gboolean toplevel);
-	char *		   (* get_link_message)		(EphyEmbed *embed);
-	char *		   (* get_js_status)		(EphyEmbed *embed);
-	int		   (* shistory_n_items)		(EphyEmbed *embed);
-	void		   (* shistory_get_nth)		(EphyEmbed *embed,
-							 int nth,
-							 gboolean is_relative,
-							 char **url,
-							 char **title);
-	int		   (* shistory_get_pos)		(EphyEmbed *embed);
-	void		   (* shistory_go_nth)		(EphyEmbed *embed,
-							 int nth);
-	void		   (* shistory_copy)		(EphyEmbed *source,
-							 EphyEmbed *dest,
-							 gboolean copy_back,
-							 gboolean copy_forward,
-							 gboolean copy_current);
-	void		   (* get_security_level)	(EphyEmbed *embed,
-						  	 EphyEmbedSecurityLevel *level,
-						  	 char **description);
-	void		   (* show_page_certificate)	(EphyEmbed *embed);
-	void		   (* set_zoom)			(EphyEmbed *embed,
-							 float zoom);
-	float		   (* get_zoom)			(EphyEmbed *embed);
-	void		   (* scroll_lines)		(EphyEmbed *embed,
-							 int num_lines);
-	void		   (* scroll_pages)		(EphyEmbed *embed,
-	 						 int num_pages);
-	void		   (* scroll_pixels)		(EphyEmbed *embed,
-							 int dx,
-							 int dy);
-	char *		   (* get_encoding)		(EphyEmbed *embed);
-	gboolean	   (* has_automatic_encoding)	(EphyEmbed *embed);
-	void		   (* set_encoding)		(EphyEmbed *embed,
-							 const char *encoding);
-	void		   (* print)			(EphyEmbed *embed);
-	void		   (* set_print_preview_mode)	(EphyEmbed *embed,
-							 gboolean mode);
-	int		   (* print_preview_n_pages)	(EphyEmbed *embed);
-	void		   (* print_preview_navigate)	(EphyEmbed *embed,
-							 EphyEmbedPrintPreviewNavType type,
-							 int page);
-	gboolean	   (* has_modified_forms)	(EphyEmbed *embed);
-	void		   (* close)			(EphyEmbed *embed);
-
+	void		   (* load_url)			  (EphyEmbed *embed,
+							   const char *url);
+	void		   (* load)			  (EphyEmbed *embed,
+							   const char *url,
+							   EphyEmbedLoadFlags flags,
+							   EphyEmbed *referring_embed);
+	void		   (* stop_load)		  (EphyEmbed *embed);
+	void		   (* reload)			  (EphyEmbed *embed,
+							   gboolean force);
+	gboolean	   (* can_go_back)		  (EphyEmbed *embed);
+	gboolean	   (* can_go_forward)		  (EphyEmbed *embed);
+	gboolean	   (* can_go_up)		  (EphyEmbed *embed);
+	GSList *	   (* get_go_up_list)		  (EphyEmbed *embed);
+	void		   (* go_back)			  (EphyEmbed *embed);
+	void		   (* go_forward)		  (EphyEmbed *embed);
+	void		   (* go_up)			  (EphyEmbed *embed);
+	const char *	   (* get_title)		  (EphyEmbed *embed);
+	char *		   (* get_location)		  (EphyEmbed *embed,
+							   gboolean toplevel);
+	const char *	   (* get_link_message)		  (EphyEmbed *embed);
+	char *		   (* get_js_status)		  (EphyEmbed *embed);
+	void		   (* shistory_copy)		  (EphyEmbed *source,
+							   EphyEmbed *dest,
+							   gboolean copy_back,
+							   gboolean copy_forward,
+							   gboolean copy_current);
+	void		   (* get_security_level)	  (EphyEmbed *embed,
+							   EphyEmbedSecurityLevel *level,
+							   char **description);
+	void		   (* show_page_certificate)	  (EphyEmbed *embed);
+	void		   (* set_zoom)			  (EphyEmbed *embed,
+							   float zoom);
+	float		   (* get_zoom)			  (EphyEmbed *embed);
+	void		   (* scroll_lines)		  (EphyEmbed *embed,
+							   int num_lines);
+	void		   (* scroll_pages)		  (EphyEmbed *embed,
+							   int num_pages);
+	void		   (* scroll_pixels)		  (EphyEmbed *embed,
+							   int dx,
+							   int dy);
+	char *		   (* get_encoding)		  (EphyEmbed *embed);
+	gboolean	   (* has_automatic_encoding)	  (EphyEmbed *embed);
+	void		   (* set_encoding)		  (EphyEmbed *embed,
+							   const char *encoding);
+	void		   (* print)			  (EphyEmbed *embed);
+	void		   (* set_print_preview_mode)	  (EphyEmbed *embed,
+							   gboolean mode);
+	int		   (* print_preview_n_pages)	  (EphyEmbed *embed);
+	void		   (* print_preview_navigate)	  (EphyEmbed *embed,
+							   EphyEmbedPrintPreviewNavType type,
+							   int page);
+	gboolean	   (* has_modified_forms)	  (EphyEmbed *embed);
+	void		   (* close)			  (EphyEmbed *embed);
+	EphyEmbedDocumentType	(* get_document_type)	  (EphyEmbed *embed);
+	int		   (* get_load_percent)		  (EphyEmbed *embed);
+	gboolean	   (* get_load_status)		  (EphyEmbed *embed);
+	EphyEmbedNavigationFlags (* get_navigation_flags) (EphyEmbed *embed);
+	const char *	   (* get_typed_address)	  (EphyEmbed *embed);
+	void		   (* set_typed_address)	  (EphyEmbed *embed,
+							   const char *address,
+							   EphyEmbedAddressExpire expire);
+	const char *	   (* get_address)		  (EphyEmbed *embed);
+	const char *	   (* get_status_message)	  (EphyEmbed *embed);
+	GdkPixbuf *	   (* get_icon)			  (EphyEmbed *embed);
+	const char *	   (* get_icon_address)		  (EphyEmbed *embed);
+	gboolean	   (* get_is_blank)		  (EphyEmbed *embed);
+	const char *	   (* get_loading_title)	  (EphyEmbed *embed);
+	gboolean	   (* get_visibility)		  (EphyEmbed *embed);
+	GList *		   (* get_backward_history)	  (EphyEmbed *embed);
+	GList *		   (* get_forward_history)	  (EphyEmbed *embed);
+	EphyHistoryItem *  (* get_next_history_item)	  (EphyEmbed *embed);
+	EphyHistoryItem *  (* get_previous_history_item)  (EphyEmbed *embed);
+	void		   (* go_to_history_item)	  (EphyEmbed *embed,
+							   EphyHistoryItem *history_item);
 };
 
-GType 		  ephy_embed_net_state_get_type		(void);
+GType		  ephy_embed_net_state_get_type		(void);
 
 GType		  ephy_embed_chrome_get_type		(void);
 
-GType 		  ephy_embed_ppv_navigation_get_type	(void);
+GType		  ephy_embed_ppv_navigation_get_type	(void);
 
 GType		  ephy_embed_security_level_get_type	(void);
 
@@ -256,12 +261,11 @@ void		  ephy_embed_stop_load			(EphyEmbed *embed);
 void		  ephy_embed_reload			(EphyEmbed *embed,
 							 gboolean force);
 
-char 		 *ephy_embed_get_title			(EphyEmbed *embed);
+const char	 *ephy_embed_get_title			(EphyEmbed *embed);
 
 char		 *ephy_embed_get_location		(EphyEmbed *embed,
 							 gboolean toplevel);
-
-char		 *ephy_embed_get_link_message		(EphyEmbed *embed);
+const char	 *ephy_embed_get_link_message		(EphyEmbed *embed);
 
 char		 *ephy_embed_get_js_status		(EphyEmbed *embed);
 
@@ -272,7 +276,7 @@ gboolean	  ephy_embed_can_go_forward		(EphyEmbed *embed);
 
 gboolean	  ephy_embed_can_go_up			(EphyEmbed *embed);
 
-GSList 		 *ephy_embed_get_go_up_list		(EphyEmbed *embed);
+GSList		 *ephy_embed_get_go_up_list		(EphyEmbed *embed);
 
 void		  ephy_embed_go_back			(EphyEmbed *embed);
 
@@ -280,19 +284,6 @@ void		  ephy_embed_go_forward			(EphyEmbed *embed);
 
 void		  ephy_embed_go_up			(EphyEmbed *embed);
 
-int		  ephy_embed_shistory_n_items		(EphyEmbed *embed);
-
-void		  ephy_embed_shistory_get_nth		(EphyEmbed *embed,
-							 int nth,
-							 gboolean is_relative,
-							 char **url,
-							 char **title);
-
-int		  ephy_embed_shistory_get_pos		(EphyEmbed *embed);
-
-void		  ephy_embed_shistory_go_nth		(EphyEmbed *embed,
-							 int nth);
-
 void		  ephy_embed_shistory_copy		(EphyEmbed *source,
 							 EphyEmbed *dest,
 							 gboolean copy_back,
@@ -301,7 +292,7 @@ void		  ephy_embed_shistory_copy		(EphyEmbed *source,
 
 void		  ephy_embed_get_security_level		(EphyEmbed *embed,
 							 EphyEmbedSecurityLevel *level,
-						 	 char **description);
+							 char **description);
 
 void		  ephy_embed_show_page_certificate	(EphyEmbed *embed);
 
@@ -321,7 +312,41 @@ void		  ephy_embed_page_scroll		(EphyEmbed *embed,
 void		  ephy_embed_scroll_pixels		(EphyEmbed *embed,
 							 int dx,
 							 int dy);
+/* Document type */
+EphyEmbedDocumentType	ephy_embed_get_document_type	(EphyEmbed *embed);
 
+/* Progress */
+int		 ephy_embed_get_load_percent		(EphyEmbed *embed);
+
+/* Load status */
+gboolean	 ephy_embed_get_load_status		(EphyEmbed *embed);
+
+/* Navigation flags */
+
+EphyEmbedNavigationFlags ephy_embed_get_navigation_flags (EphyEmbed *embed);
+
+/* Typed address */
+const char	 *ephy_embed_get_typed_address		(EphyEmbed *embed);
+void		 ephy_embed_set_typed_address		(EphyEmbed *embed,
+							 const char *address,
+							 EphyEmbedAddressExpire expire);
+/* Address */
+const char *	 ephy_embed_get_address			(EphyEmbed *embed);
+
+/* Status messages */
+const char *	   ephy_embed_get_status_message	(EphyEmbed *embed);
+
+/* Icon and Icon Address */
+
+GdkPixbuf *	   ephy_embed_get_icon			(EphyEmbed *embed);
+const char *	   ephy_embed_get_icon_address		(EphyEmbed *embed);
+
+/* Is blank */
+gboolean	  ephy_embed_get_is_blank		(EphyEmbed *embed);
+
+const char *	 ephy_embed_get_loading_title		(EphyEmbed *embed);
+
+gboolean	 ephy_embed_get_visibility		(EphyEmbed *embed);
 /* Encoding */
 char		 *ephy_embed_get_encoding		(EphyEmbed *embed);
 
@@ -347,6 +372,13 @@ void		  ephy_embed_close			(EphyEmbed *embed);
 
 gboolean	  ephy_embed_has_modified_forms		(EphyEmbed *embed);
 
+/* History */
+GList		*ephy_embed_get_backward_history	(EphyEmbed *embed);
+GList		*ephy_embed_get_forward_history		(EphyEmbed *embed);
+EphyHistoryItem *ephy_embed_get_next_history_item	(EphyEmbed *embed);
+EphyHistoryItem *ephy_embed_get_previous_history_item	(EphyEmbed *embed);
+void		 ephy_embed_go_to_history_item		(EphyEmbed *embed, EphyHistoryItem *history_item);
+
 G_END_DECLS
 
 #endif
