@@ -15,9 +15,9 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: EventContext.cpp,v 1.68 2006/09/29 19:32:19 chpe Exp $
+ *  $Id$
  */
 
 #include "mozilla-config.h"
@@ -968,9 +968,10 @@ nsresult EventContext::SetStringProperty (const char *name, const char *value)
 	GValue *val = g_new0 (GValue, 1);
 
 	g_value_init (val, G_TYPE_STRING);
-	
-	g_value_set_string (val, value);
-			 
+
+	char *copy = g_strstrip (g_strdup (value));	
+	g_value_take_string (val, copy);
+
 	mozilla_embed_event_set_property (mEmbedEvent, name, val);
 
 	return NS_OK;
