@@ -15,13 +15,14 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-toolbar.c,v 1.35 2006/12/15 14:01:57 chpe Exp $
+ *  $Id$
  */
 
 #include "config.h"
 
+#include "ephy-embed-container.h"
 #include "ephy-toolbar.h"
 #include "ephy-link.h"
 #include "ephy-go-action.h"
@@ -40,12 +41,7 @@
 #include "ephy-debug.h"
 
 #include <glib/gi18n.h>
-#include <gtk/gtkstock.h>
-#include <gtk/gtkuimanager.h>
-#include <gtk/gtktoolitem.h>
-#include <gtk/gtktoolbutton.h>
-#include <gtk/gtkseparatortoolitem.h>
-#include <gtk/gtktoolbar.h>
+#include <gtk/gtk.h>
 #include <string.h>
 
 enum
@@ -104,9 +100,16 @@ enum
 	LAST_SIGNAL
 };
 
-static guint signals[LAST_SIGNAL] = { 0 };
+static guint signals[LAST_SIGNAL];
 
-static GObjectClass *parent_class = NULL;
+static void
+ephy_toolbar_iface_init (EphyLinkIface *iface)
+{
+}
+
+G_DEFINE_TYPE_WITH_CODE (EphyToolbar, ephy_toolbar, EGG_TYPE_EDITABLE_TOOLBAR,
+                         G_IMPLEMENT_INTERFACE (EPHY_TYPE_LINK,
+                                                ephy_toolbar_iface_init))
 
 /* helper functions */
 
@@ -168,21 +171,21 @@ sync_user_input_cb (EphyLocationAction *action,
 		    EphyToolbar *toolbar)
 {
 	EphyToolbarPrivate *priv = toolbar->priv;
-	EphyTab *tab;
+	EphyEmbed *embed;
 	const char *address;
 
 	LOG ("sync_user_input_cb");
 
 	if (priv->updating_address) return;
 
-	tab = ephy_window_get_active_tab (priv->window);
-	g_return_if_fail (EPHY_IS_TAB (tab));
+	embed = ephy_embed_container_get_active_child (EPHY_EMBED_CONTAINER (priv->window));
+        g_assert (EPHY_IS_EMBED (embed));
 
 	address = ephy_location_action_get_address (action);
 
 	priv->updating_address = TRUE;
-	ephy_tab_set_typed_address (tab, address,
-				    EPHY_TAB_ADDRESS_EXPIRE_CURRENT);
+	ephy_embed_set_typed_address (embed, address,
+                                      EPHY_EMBED_ADDRESS_EXPIRE_CURRENT);
 	priv->updating_address = FALSE;
 }
 
@@ -456,6 +459,26 @@ ephy_toolbar_set_navigation_actions (EphyToolbar *toolbar,
 	ephy_action_change_sensitivity_flags (priv->actions[UP_ACTION], SENS_FLAG, !up);
 }
 
+void
+ephy_toolbar_set_navigation_tooltips (EphyToolbar *toolbar,
+				      const char *back_title,
+				      const char *forward_title)
+{
+	EphyToolbarPrivate *priv = toolbar->priv;
+	GValue value = { 0 };
+
+	g_value_init (&value, G_TYPE_STRING);
+
+	g_value_set_static_string (&value, back_title);
+	g_object_set_property (G_OBJECT (priv->actions[BACK_ACTION]),
+			       "tooltip", &value);
+
+	g_value_set_static_string (&value, forward_title);
+	g_object_set_property (G_OBJECT (priv->actions[FORWARD_ACTION]),
+			       "tooltip", &value);
+	g_value_unset (&value);
+}
+
 void
 ephy_toolbar_set_security_state (EphyToolbar *toolbar,
 				 gboolean is_secure,
@@ -503,13 +526,13 @@ ephy_toolbar_set_zoom (EphyToolbar *toolbar,
 static void
 ephy_toolbar_realize (GtkWidget *widget)
 {
-	GTK_WIDGET_CLASS (parent_class)->realize (widget);
+	GTK_WIDGET_CLASS (ephy_toolbar_parent_class)->realize (widget);
 }
 
 static void
 ephy_toolbar_unrealize (GtkWidget *widget)
 {
-	GTK_WIDGET_CLASS (parent_class)->unrealize (widget);
+	GTK_WIDGET_CLASS (ephy_toolbar_parent_class)->unrealize (widget);
 }
 
 static void
@@ -517,7 +540,7 @@ ephy_toolbar_show (GtkWidget *widget)
 {
 	EphyToolbar *toolbar = EPHY_TOOLBAR (widget);
 
-	GTK_WIDGET_CLASS (parent_class)->show (widget);
+	GTK_WIDGET_CLASS (ephy_toolbar_parent_class)->show (widget);
 
 	ephy_toolbar_update_spinner (toolbar);
 }
@@ -527,7 +550,7 @@ ephy_toolbar_hide (GtkWidget *widget)
 {
 	EphyToolbar *toolbar = EPHY_TOOLBAR (widget);
 
-	GTK_WIDGET_CLASS (parent_class)->hide (widget);
+	GTK_WIDGET_CLASS (ephy_toolbar_parent_class)->hide (widget);
 
 	ephy_toolbar_update_spinner (toolbar);
 }
@@ -550,8 +573,9 @@ ephy_toolbar_constructor (GType type,
 	EphyToolbarPrivate *priv;
 	GtkToolbar *gtoolbar;
 
-	object = parent_class->constructor (type, n_construct_properties,
-					    construct_params);
+	object = G_OBJECT_CLASS (ephy_toolbar_parent_class)->constructor (type,
+                                                                          n_construct_properties,
+                                                                          construct_params);
 
 	toolbar = EPHY_TOOLBAR (object);
 	priv = toolbar->priv;
@@ -593,7 +617,7 @@ ephy_toolbar_finalize (GObject *object)
 					     priv->set_focus_handler);
 	}
 
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+	G_OBJECT_CLASS (ephy_toolbar_parent_class)->finalize (object);
 }
 
 static void
@@ -628,8 +652,6 @@ ephy_toolbar_class_init (EphyToolbarClass *klass)
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
-	parent_class = g_type_class_peek_parent (klass);
-
 	object_class->constructor = ephy_toolbar_constructor;
 	object_class->finalize = ephy_toolbar_finalize;
 	object_class->set_property = ephy_toolbar_set_property;
@@ -684,43 +706,6 @@ ephy_toolbar_class_init (EphyToolbarClass *klass)
 	g_type_class_add_private (object_class, sizeof(EphyToolbarPrivate));
 }
 
-GType
-ephy_toolbar_get_type (void)
-{
-	static GType type = 0;
-
-	if (G_UNLIKELY (type == 0))
-	{
-		const GTypeInfo our_info =
-		{
-			sizeof (EphyToolbarClass),
-			NULL, /* base_init */
-			NULL, /* base_finalize */
-			(GClassInitFunc) ephy_toolbar_class_init,
-			NULL,
-			NULL, /* class_data */
-			sizeof (EphyToolbar),
-			0, /* n_preallocs */
-			(GInstanceInitFunc) ephy_toolbar_init
-		};
-		const GInterfaceInfo link_info = 
-		{
-			NULL,
-			NULL,
-			NULL
-		};
-
-		type = g_type_register_static (EGG_TYPE_EDITABLE_TOOLBAR,
-					       "EphyToolbar",
-					       &our_info, 0);
-		g_type_add_interface_static (type,
-					     EPHY_TYPE_LINK,
-					     &link_info);
-	}
-
-	return type;
-}
-
 EphyToolbar *
 ephy_toolbar_new (EphyWindow *window)
 {
